==> xlniuxdata-vipgame-1.0.7-20150331.092636-2-sources.jar: com/xunlei/niux/data/vipgame/vo/CpsGames.java <==
package com.xunlei.niux.data.vipgame.vo;

import com.ferret.common.dao.annotation.Table;

/**
 * cps游戏基本信息
 * @author 李苏
 * @date 2015-3-11
 * @Descripter:
 *
 */
@Table(tableName="cpsgames",pkFieldName="seqId",pkFieldAssign=false)
public class CpsGames {

	private Long seqId;
	private String gameId;
	private String gameNo;
	private String gameName;
	private String gameDesc;
    private Integer gameFeature;
    private Long displayOrder;
	private Integer status;
	private String remark;
	private String inputBy;
	private String inputTime;
	private String editBy;
	private String editTime;
    private String simpleName;
    private String picUrl;
    private String iconUrl;
    private String downLoadUrl;
    private String mulPhotoUrl;
    private String cpsSize;
    private Integer downloadNum;

    public String getCpsSize() {
        return cpsSize;
    }

    public void setCpsSize(String cpsSize) {
        this.cpsSize = cpsSize;
    }

    public Long getDisplayOrder() {
        return displayOrder;
    }

    public void setDisplayOrder(Long displayOrder) {
        this.displayOrder = displayOrder;
    }

    public Integer getDownloadNum() {
        return downloadNum;
    }

    public void setDownloadNum(Integer downloadNum) {
        this.downloadNum = downloadNum;
    }

    public String getDownLoadUrl() {
        return downLoadUrl;
    }

    public void setDownLoadUrl(String downLoadUrl) {
        this.downLoadUrl = downLoadUrl;
    }

    public String getEditBy() {
        return editBy;
    }

    public void setEditBy(String editBy) {
        this.editBy = editBy;
    }

    public String getEditTime() {
        return editTime;
    }

    public void setEditTime(String editTime) {
        this.editTime = editTime;
    }

    public String getGameDesc() {
        return gameDesc;
    }

    public void setGameDesc(String gameDesc) {
        this.gameDesc = gameDesc;
    }

    public Integer getGameFeature() {
        return gameFeature;
    }

    public void setGameFeature(Integer gameFeature) {
        this.gameFeature = gameFeature;
    }

    public String getGameId() {
        return gameId;
    }

    public void setGameId(String gameId) {
        this.gameId = gameId;
    }

    public String getGameName() {
        return gameName;
    }

    public void setGameName(String gameName) {
        this.gameName = gameName;
    }

    public String getGameNo() {
        return gameNo;
    }

    public void setGameNo(String gameNo) {
        this.gameNo = gameNo;
    }

    public String getIconUrl() {
        return iconUrl;
    }

    public void setIconUrl(String iconUrl) {
        this.iconUrl = iconUrl;
    }

    public String getInputBy() {
        return inputBy;
    }

    public void setInputBy(String inputBy) {
        this.inputBy = inputBy;
    }

    public String getInputTime() {
        return inputTime;
    }

    public void setInputTime(String inputTime) {
        this.inputTime = inputTime;
    }

    public String getMulPhotoUrl() {
        return mulPhotoUrl;
    }

    public void setMulPhotoUrl(String mulPhotoUrl) {
        this.mulPhotoUrl = mulPhotoUrl;
    }

    public String getPicUrl() {
        return picUrl;
    }

    public void setPicUrl(String picUrl) {
        this.picUrl = picUrl;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public Long getSeqId() {
        return seqId;
    }

    public void setSeqId(Long seqId) {
        this.seqId = seqId;
    }

    public String getSimpleName() {
        return simpleName;
    }

    public void setSimpleName(String simpleName) {
        this.simpleName = simpleName;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }
}

==> xlniuxdata-vipgame-1.0.13-20150507.085016-2-sources.jar: com/xunlei/niux/data/vipgame/vo/CpsGames.java <==
package com.xunlei.niux.data.vipgame.vo;

import com.ferret.common.dao.annotation.Table;

/**
 * cps游戏基本信息
 * @author 李苏
 * @date 2015-3-11
 * @Descripter:
 *
 */
@Table(tableName="cpsgames",pkFieldName="seqId",pkFieldAssign=false)
public class CpsGames {

	private Long seqId;
	private String gameId;
	private String gameNo;
	private String gameName;
	private String gameDesc;
    private Integer gameFeature;
    private Long displayOrder;
	private Integer status;
	private String remark;
	private String inputBy;
	private String inputTime;
	private String editBy;
	private String editTime;
    private String simpleName;
    private String picUrl;
    private String iconUrl;
    private String downLoadUrl;
    private String mulPhotoUrl;
    private String cpsSize;
    private Integer downloadNum;
    private Integer sourceType;
    private Integer mobileGameType;
    private String packageName;
    private Integer xiaomiappId;

    public String getCpsSize() {
        return cpsSize;
    }

    public void setCpsSize(String cpsSize) {
        this.cpsSize = cpsSize;
    }

    public Long getDisplayOrder() {
        return displayOrder;
    }

    public void setDisplayOrder(Long displayOrder) {
        this.displayOrder = displayOrder;
    }

    public Integer getDownloadNum() {
        return downloadNum;
    }

    public void setDownloadNum(Integer downloadNum) {
        this.downloadNum = downloadNum;
    }

    public String getDownLoadUrl() {
        return downLoadUrl;
    }

    public void setDownLoadUrl(String downLoadUrl) {
        this.downLoadUrl = downLoadUrl;
    }

    public String getEditBy() {
        return editBy;
    }

    public void setEditBy(String editBy) {
        this.editBy = editBy;
    }

    public String getEditTime() {
        return editTime;
    }

    public void setEditTime(String editTime) {
        this.editTime = editTime;
    }

    public String getGameDesc() {
        return gameDesc;
    }

    public void setGameDesc(String gameDesc) {
        this.gameDesc = gameDesc;
    }

    public Integer getGameFeature() {
        return gameFeature;
    }

    public void setGameFeature(Integer gameFeature) {
        this.gameFeature = gameFeature;
    }

    public String getGameId() {
        return gameId;
    }

    public void setGameId(String gameId) {
        this.gameId = gameId;
    }

    public String getGameName() {
        return gameName;
    }

    public void setGameName(String gameName) {
        this.gameName = gameName;
    }

    public String getGameNo() {
        return gameNo;
    }

    public void setGameNo(String gameNo) {
        this.gameNo = gameNo;
    }

    public String getIconUrl() {
        return iconUrl;
    }

    public void setIconUrl(String iconUrl) {
        this.iconUrl = iconUrl;
    }

    public String getInputBy() {
        return inputBy;
    }

    public void setInputBy(String inputBy) {
        this.inputBy = inputBy;
    }

    public String getInputTime() {
        return inputTime;
    }

    public void setInputTime(String inputTime) {
        this.inputTime = inputTime;
    }

    public String getMulPhotoUrl() {
        return mulPhotoUrl;
    }

    public void setMulPhotoUrl(String mulPhotoUrl) {
        this.mulPhotoUrl = mulPhotoUrl;
    }

    public String getPicUrl() {
        return picUrl;
    }

    public void setPicUrl(String picUrl) {
        this.picUrl = picUrl;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public Long getSeqId() {
        return seqId;
    }

    public void setSeqId(Long seqId) {
        this.seqId = seqId;
    }

    public String getSimpleName() {
        return simpleName;
    }

    public void setSimpleName(String simpleName) {
        this.simpleName = simpleName;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public Integer getSourceType() {
        return sourceType;
    }

    public void setSourceType(Integer sourceType) {
        this.sourceType = sourceType;
    }

    public Integer getMobileGameType() {
        return mobileGameType;
    }

    public void setMobileGameType(Integer mobileGameType) {
        this.mobileGameType = mobileGameType;
    }

    public String getPackageName() {
        return packageName;
    }

    public void setPackageName(String packageName) {
        this.packageName = packageName;
    }

    public Integer getXiaomiappId() {
        return xiaomiappId;
    }

    public void setXiaomiappId(Integer xiaomiappId) {
        this.xiaomiappId = xiaomiappId;
    }
}
